/*
 * Implementation of the proxy interface for communicating with Rhythmbox.
 *
 * Rhythmbox Applet
 * Copyright (C) 2004-2005 Paul Kuliniewicz <kuliniew@purdue.edu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02111-1301, USA.
 *
 */

#include <config.h>

#include "rb-proxy.h"

#include "rb-song-metadata.h"

/* Function declarations */

static void rb_proxy_base_init (gpointer g_class);

/* GType stuff */

static void
rb_proxy_base_init (gpointer g_class)
{
	static gboolean initialized = FALSE;

	if (!initialized)
	{
		g_object_interface_install_property (g_class,
						     g_param_spec_object ("song",
									  "song",
									  "Currently playing song",
									  RB_TYPE_SONG_METADATA,
									  G_PARAM_READABLE));

		g_object_interface_install_property (g_class,
						     g_param_spec_long ("elapsed",
									"elapsed",
									"Elapsed time, in seconds",
									-1,
									G_MAXLONG,
									-1,
									G_PARAM_READABLE));

		g_object_interface_install_property (g_class,
						     g_param_spec_double ("rating",
									  "rating",
									  "Rating of current song",
									  0.0,
									  5.0,
									  0.0,
									  G_PARAM_READWRITE));

		g_object_interface_install_property (g_class,
						     g_param_spec_boolean ("connected",
									   "connected",
									   "Whether the proxy is connected to Rhythmbox",
									   FALSE,
									   G_PARAM_READABLE));

		g_object_interface_install_property (g_class,
						     g_param_spec_boolean ("playing",
									   "playing",
									   "Whether Rhythmbox is playing",
									   FALSE,
									   G_PARAM_READABLE));

		g_object_interface_install_property (g_class,
						     g_param_spec_boolean ("pausable",
									   "pausable",
									   "Whether playback can be paused",
									   FALSE,
									   G_PARAM_READABLE));

		initialized = TRUE;
	}
}

GType
rb_proxy_get_type (void)
{
	static GType type = 0;

	if (type == 0)
	{
		static const GTypeInfo info = {
			sizeof (RbProxyClass), 		/* class_size */
			rb_proxy_base_init, 		/* base_init */
			NULL,				/* base_finalize */
			NULL,				/* class_init */
			NULL,				/* class_finalize */
			NULL,				/* class_data */
			0, 				/* instance_size */
			0,				/* n_preallocs */
			NULL,				/* instance_init */
			NULL
		};

		type = g_type_register_static (G_TYPE_INTERFACE, "RbProxy", &info, 0);
		g_type_interface_add_prerequisite (type, G_TYPE_OBJECT);
	}

	return type;
}

/* Virtual method dispatchers */

void
rb_proxy_play_pause_stop (RbProxy *proxy)
{
	(RB_PROXY_GET_CLASS (proxy))->play_pause_stop (proxy);
}

void
rb_proxy_previous (RbProxy *proxy)
{
	(RB_PROXY_GET_CLASS (proxy))->previous (proxy);
}

void
rb_proxy_next (RbProxy *proxy)
{
	(RB_PROXY_GET_CLASS (proxy))->next (proxy);
}
